import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;
/**
 * The ball will move throughout the world and become more transparent.
 * 
 * Brandon Cannuli 
 * April 16, 2016
 */
public class Ball extends Actor
{
    private static final int MAXSIZE = 100;
    private int speed;

    /**  
     * Create a ball.
     */
    public Ball(int direction)
    {
        setMyImage();
        setRotation(direction);
        speed = Greenfoot.getRandomNumber(5) + 1;
    }

    /**
     * Set an image with a random sized and colored circle. 
     */
    private void setMyImage()
    {
        GreenfootImage img = new GreenfootImage(MAXSIZE,MAXSIZE);
        img.setColor(randomColor());
        int size = Greenfoot.getRandomNumber(MAXSIZE);
        img.fillOval(0, 0, size, size);
        setImage(img);   
    }

    /**
     * Create and return a random color.
     */
    private Color randomColor()
    {
        int r = Greenfoot.getRandomNumber(256);
        int g = Greenfoot.getRandomNumber(256);
        int b = Greenfoot.getRandomNumber(256);
        int alpha = Greenfoot.getRandomNumber(256);
        return new Color(r,g,b,alpha);
    }

    /**
     * Act - do whatever the Ball wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        move(speed);
        if(isAtEdge())
        {
            turn(153);
        }    
        changeTransparency();
    }

    /**
     * Make the ball more transparent. If it is completely transparent, remove it.
     */
    void changeTransparency()
    {
        GreenfootImage img = getImage();
        int alpha = img.getTransparency();
        if (alpha > 0)
        {
            img.setTransparency(alpha-1);
        }
        else
        {
            getWorld().removeObject(this);
        }
    }

    /**
     * Test if we are close to one of the edges of the world.
     */
    public boolean isAtEdge()
    {

        if(getX() < 10 || getX() > getWorld().getWidth() - 10)  
            return true;  
        if(getY() < 10 || getY() > getWorld().getHeight() - 10)  
            return true;  
        else 
            return false;  
    }
}